==> nextcloud-25.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/photos/l10n/zh_TW.js <==
OC.L10N.register(
    "photos",
    {
    "Photos" : "照片",
    "Your memories under your control" : "完全自主掌控您珍貴的回憶",
    "All media" : "所有媒體",
    "Videos" : "影片",
    "Albums" : "相簿",
    "Collaborative albums" : "協作相簿",
    "People" : "人物",
    "Folders" : "資料夾",
    "Favorites" : "我的最愛",
    "On this day" : "在這天",
    "Shared with you" : "與您分享",
    "Tags" : "標籤",
    "Locations" : "地點",
    "Photos settings" : "照片設定",
    "Mark selection as favorite" : "將選取範圍標記為最愛",
    "Add selection to favorites" : "新增選取範圍至最愛",
    "Remove selection from favorites" : "從最愛移除選取範圍",
    "Name of the album" : "相簿名稱",
    "Location of the album" : "相簿位置",
    "Go back to the previous view." : "回到上一個檢視。",
    "Back" : "返回",
    "Go to the add collaborators view." : "到新增協作者檢視",
    "Add collaborators" : "新增協作者",
    "Save." : "儲存。",
    "Create the album." : "建立相簿。",
    "Save" : "儲存",
    "Create album" : "建立相簿",
    "Back to the new album form." : "回到新相簿表單。",
    "Add to Album" : "新增至相簿",
    "Add selection to album {ablumName}" : "新增選取範圍至相簿 {ablumName}",
    "Create a new album." : "建立新相簿。",
    "Create new album" : "建立新相簿",
    "New album" : "新相簿",
    "_%n item_::_%n photos and videos_" : ["%n 個照片與影片"],
    "_Share with %n user_::_Share with %n users_" : ["與 %n 個使用者分享"],
    "Add people or groups who can edit your album" : "新增可以編輯您的相簿的使用者或群組",
    "Search for collaborators" : "搜尋協作者",
    "Search people or groups" : "搜尋使用者或群組",
    "Add {collaboratorLabel} to the collaborators list" : "新增 {collaboratorLabel} 至協作者清單",
    "No collaborators available" : "沒有可用的協作者",
    "Remove {collaboratorLabel} from the collaborators list" : "從協作者清單移除 {collaboratorLabel}",
    "Public link copied!" : "已複製公開連結！",
    "Copy public link" : "複製公開連結",
    "Share via public link" : "透過公開連結分享",
    "Failed to fetch collaborators list." : "擷取協作者清單失敗。",
    "This collection does not exist" : "此收藏不存在",
    "An error occurred" : "發生錯誤",
    "_%n photos_::_%n photos_" : ["%n 個照片"],
    "Select image {imageName}" : "選取圖片 {imageName}",
    "The file is in the favorites" : "檔案在最愛中",
    "Open the full size \"{name}\" image" : "開啟「{name}」的原始尺寸影像",
    "There are no photos or videos yet!" : "還沒有照片或影片！",
    "Add to {destination}" : "新增至 {destination}",
    "Open the \"{name}\" sub-directory" : "開啟「{name}」子目錄",
    "Back to {folder}" : "回到 {folder}",
    "Share this folder" : "分享此資料夾",
    "_{years} year ago_::_{years} years ago_" : ["{years} 年前"],
    "Enable squared photos view" : "啟用方形照片檢視",
    "Default Photos upload and Albums location" : "預設照片上傳與相簿位置",
    "Select the default location for your media" : "選取您媒體的預設位置",
    "Invalid location selected" : "選取無效的位置",
    "View" : "檢視",
    "Photos directory" : "照片目錄",
    "_%n photo_::_%n photos_" : ["%n 張照片"],
    "Manage collaborators for this album" : "管理此相簿的協作者",
    "Open actions menu" : "開啟動作選單",
    "Edit album details" : "編輯相簿詳細資訊",
    "Download all files in album" : "下載相簿中的所有檔案",
    "Delete album" : "刪除相簿",
    "Download selected files" : "下載已選取的檔案",
    "Remove selection from album" : "從相簿移除選取範圍",
    "This album does not have any photos or videos yet!" : "此相簿還沒有任何照片或影片！",
    "Add photos to this album" : "新增照片至此相簿",
    "Add photos to the album" : "將照片新增至相簿",
    "Manage collaborators" : "管理協作者",
    "Save collaborators for this album." : "儲存此相簿的協作者。",
    "Cover photo for album {albumName}" : "相簿 {albumName} 的封面照片",
    "There is no album yet!" : "尚無相簿！",
    "This person could not be found" : "找不到此人",
    "Rename person" : "重新命名人",
    "Merge with different person" : "與其他人合併",
    "Download selected photos" : "下載選定的照片",
    "Favorite" : "收藏",
    "Remove from favorites" : "從最愛中移除",
    "Remove person" : "移除人",
    "Name of this person" : "此人的名字",
    "Merge person" : "合併人",
    "_Remove photo from person_::_Remove photos from person_" : ["從人移除照片"],
    "This might take some time depending on the size of your photo library." : "這可能需要花一點時間，取決於您照片庫的大小。",
    "Recognized people will show up here" : "被識別的人將會出現在此處",
    "This folder does not exist" : "此資料夾不存在",
    "Loading folders …" : "正在載入資料夾……",
    "No photos in here" : "此處無圖片檔案",
    "Shared albums" : "已分享相簿",
    "Cover photo for shared album {albumName}." : "共享相簿 {albumName}. 的封面照片",
    "Back to tags overview" : "回到標籤概覽",
    "No photos with this tag yet" : "還沒有帶有此標籤的照片",
    "No tags yet" : "尚未加入標籤",
    "Photos with tags will show up here" : "此處會顯示圖片的標籤",
    "Popular tags" : "熱門標籤",
    "Add" : "新增",
    "Create a new album" : "建立新相簿",
    "Add selection to an album" : "將選取範圍新增至相簿",
    "Add to album" : "新增至相簿",
    "Delete selection" : "刪除選擇",
    "Failed to fetch faces list." : "擷取臉部清單失敗。",
    "All your media" : "您所有的媒體",
    "Tagged photos" : "有標籤的照片",
    "Failed to create {albumName}." : "建立 {albumName} 失敗。",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "重新命名 {currentAlbumName} 為 {newAlbumName} 失敗。",
    "Failed to rename {oldName} to {faceName}." : "重新命名 {oldName} 為 {faceName} 失敗。",
    "Failed to delete {faceName}." : "刪除 {faceName} 失敗。",
    "Failed to delete {fileId}." : "刪除 {fileId} 失敗。",
    "Failed to delete {fileName}." : "刪除 {fileName} 失敗。",
    "Failed to set favorite state for {fileId}." : "未能為 {fileId} 設定最愛狀態。",
    "Failed to set favorite state for {fileName}." : "未能為 {fileName} 設定最愛狀態。",
    "Your photos" : "我的照片",
    "Your videos" : "您的影片",
    "Your folders" : "您的資料夾",
    "Settings" : "設定"
},
"nplurals=1; plural=0;");

==> nextcloud-28.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/photos/l10n/zh_TW.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "公開連結",
    "Photos" : "照片",
    "Your memories under your control" : "完全自主掌控您珍貴的回憶",
    "All media" : "所有媒體",
    "Videos" : "影片",
    "Albums" : "相簿",
    "Collaborative albums" : "協作相簿",
    "People" : "人物",
    "Folders" : "資料夾",
    "Favorites" : "我的最愛",
    "On this day" : "在這天",
    "Shared with you" : "與您分享",
    "Tags" : "標籤",
    "Places" : "地點",
    "Map" : "地圖",
    "Photos settings" : "照片設定",
    "Mark selection as favorite" : "將選取範圍標記為最愛",
    "Add selection to favorites" : "新增選取範圍至最愛",
    "Remove selection from favorites" : "從最愛移除選取範圍",
    "Name of the album" : "相簿名稱",
    "Location of the album" : "相簿位置",
    "Back" : "返回",
    "Add collaborators" : "新增協作者",
    "Save" : "儲存",
    "Create album" : "建立相簿",
    "Add to Album" : "新增至相簿",
    "Add selection to album {albumName}" : "新增選取範圍至相簿 {albumName}",
    "Shared by" : "分享自",
    "Create a new album." : "建立新相簿。",
    "Create new album" : "建立新相簿",
    "New album" : "新相簿",
    "_%n item_::_%n photos and videos_" : ["%n 個照片與影片"],
    "Add people or groups who can edit your album" : "新增可以編輯您的相簿的使用者或群組",
    "Search people or groups" : "搜尋使用者或群組",
    "No recommendations. Start typing." : "無建議。開始輸入。",
    "Group" : "群組",
    "Remove {collaboratorLabel} from the collaborators list" : "從協作者清單移除 {collaboratorLabel}",
    "Copy the public link" : "複製公開連結",
    "Public link copied!" : "已複製公開連結！",
    "Copy public link" : "複製公開連結",
    "Delete the public link" : "刪除公開連結",
    "Create public link share" : "建立公開連結分享",
    "Share via public link" : "透過公開連結分享",
    "Failed to fetch collaborators list." : "擷取協作者清單失敗。",
    "Failed to update album." : "更新相簿失敗。",
    "This collection does not exist" : "此收藏不存在",
    "An error occurred" : "發生錯誤",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n 個未指派的照片"],
    "Favorite" : "收藏",
    "Select image {imageName}" : "選取圖片 {imageName}",
    "Favorite image, open the full size \"{name}\" image" : "收藏影像，開啟「{name}」的原始尺寸影像",
    "Open the full size \"{name}\" image" : "開啟「{name}」的原始尺寸影像",
    "Jump to {date}" : "跳到 {date}",
    "There are no photos or videos yet!" : "還沒有照片或影片！",
    "Add to {destination}" : "新增至 {destination}",
    "Open the \"{name}\" folder" : "開啟「{name}」資料夾",
    "Go back" : "返回",
    "Back to {folder}" : "回到 {folder}",
    "Share this folder" : "分享此資料夾",
    "_{years} year ago_::_{years} years ago_" : ["{years} 年前"],
    "Enable squared photos view" : "啟用方形照片檢視",
    "Default Photos upload and Albums location" : "預設照片上傳與相簿位置",
    "Choose default Photos upload and Albums location" : "選擇預設照片上傳與相簿位置",
    "Select the default location for your media" : "選取您媒體的預設位置",
    "Invalid location selected" : "選取無效的位置",
    "View" : "檢視",
    "Photos directory" : "照片目錄",
    "_%n photo_::_%n photos_" : ["%n 張照片"],
    "Unselect all" : "取消全選",
    "Manage collaborators for this album" : "管理此相簿的協作者",
    "Open actions menu" : "開啟動作選單",
    "Edit album details" : "編輯相簿詳細資訊",
    "Download all files in album" : "下載相簿中的所有檔案",
    "Delete album" : "刪除相簿",
    "Download selected files" : "下載已選取的檔案",
    "Remove selection from album" : "從相簿移除選取範圍",
    "This album does not have any photos or videos yet!" : "此相簿還沒有任何照片或影片！",
    "Add photos to this album" : "新增照片至此相簿",
    "Add photos to {albumName}" : "新增照片至 {albumName}",
    "Manage collaborators" : "管理協作者",
    "Save collaborators for this album." : "儲存此相簿的協作者。",
    "Cover photo for album {albumName}" : "相簿 {albumName} 的封面照片",
    "There is no album yet!" : "尚無相簿！",
    "This person could not be found" : "找不到此人",
    "Rename person" : "重新命名人",
    "Merge with different person" : "與其他人合併",
    "Download selected photos" : "下載選定的照片",
    "Remove from favorites" : "從最愛中移除",
    "Remove person" : "移除人",
    "Name of this person" : "此人的名字",
    "Save." : "儲存。",
    "Merge person" : "合併人",
    "Move to different person" : "移動至其他人",
    "_Move photo to a different person_::_Move photos to a different person_" : ["將照片移動為其他人"],
    "_Remove photo from person_::_Remove photos from person_" : ["從人移除照片"],
    "This might take some time depending on the size of your photo library." : "這可能需要花一點時間，取決於您照片庫的大小。",
    "Recognized people will show up here" : "被識別的人將會出現在此處",
    "This folder does not exist" : "此資料夾不存在",
    "Loading folders …" : "正在載入資料夾……",
    "No photos in here" : "此處無圖片檔案",
    "Taken on {date} at {time}" : "拍攝於 {date} 的 {time}",
    "This place does not have any photos or videos yet!" : "此處還沒有任何照片或影片！",
    "Add photos to this place" : "新增照片至此處",
    "Cover photo for place {placeName}" : "地點 {placeName} 的封面照片",
    "There is no place yet!" : "還沒有地點！",
    "Cover photo for shared album {albumName}." : "共享相簿 {albumName}. 的封面照片",
    "Back to tags overview" : "回到標籤概覽",
    "No photos with this tag yet" : "還沒有帶有此標籤的照片",
    "No tags yet" : "尚未加入標籤",
    "Photos with tags will show up here" : "此處會顯示圖片的標籤",
    "Popular tags" : "熱門標籤",
    "Add" : "新增",
    "Add to album" : "新增至相簿",
    "Delete selection" : "刪除選擇",
    "No photos or videos in here" : "此處沒有照片或影片",
    "Unassigned faces" : "未指派的臉孔",
    "_%n photos_::_%n photos_" : ["%n 個照片"],
    "Failed to fetch collection." : "擷取收藏品失敗。",
    "Failed to fetch collections list." : "擷取收藏清單失敗。",
    "Failed to fetch faces list." : "擷取臉部清單失敗。",
    "All your media" : "您所有的媒體",
    "Album {title}" : "相簿 {title}",
    "Shared Albums" : "已分享的相簿",
    "Shared album {title}" : "已分享的相簿 {title}",
    "Public album {title}" : "公開相簿 {title}",
    "Tagged photos" : "有標籤的照片",
    "Tagged photo {title}" : "已標記的照片 {title}",
    "{title}'s face" : "{title} 的臉",
    "{startDate} to {endDate}" : "{startDate} 到 {endDate}",
    "Details" : "詳細資訊",
    "Failed to rename {oldName} to {faceName}." : "重新命名 {oldName} 為 {faceName} 失敗。",
    "Failed to delete {faceName}." : "刪除 {faceName} 失敗。",
    "Failed to delete {fileId}." : "刪除 {fileId} 失敗。",
    "Failed to delete {fileName}." : "刪除 {fileName} 失敗。",
    "Failed to set favorite state for {fileId}." : "未能為 {fileId} 設定最愛狀態。",
    "Failed to set favorite state for {fileName}." : "未能為 {fileName} 設定最愛狀態。",
    "Go back to the previous view." : "回到上一個檢視。",
    "Go to the add collaborators view." : "到新增協作者檢視",
    "Create the album." : "建立相簿。",
    "Back to the new album form." : "回到新相簿表單。",
    "_Share with %n user_::_Share with %n users_" : ["與 %n 個使用者分享"],
    "Search for collaborators" : "搜尋協作者",
    "Add {collaboratorLabel} to the collaborators list" : "新增 {collaboratorLabel} 至協作者清單",
    "No collaborators available" : "沒有可用的協作者",
    "Failed to fetch album." : "擷取相簿失敗。",
    "The file is in the favorites" : "檔案在最愛中",
    "Open the \"{name}\" sub-directory" : "開啟「{name}」子目錄",
    "Add photos to the album" : "將照片新增至相簿",
    "Failed to fetch albums list." : "擷取相簿清單失敗。",
    "Shared albums" : "已分享相簿",
    "Create a new album" : "建立新相簿",
    "Add selection to an album" : "將選取範圍新增至相簿",
    "Failed to create {albumName}." : "建立 {albumName} 失敗。",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "重新命名 {currentAlbumName} 為 {newAlbumName} 失敗。"
},
"nplurals=1; plural=0;");
